slepc-3.18.0 2022-10-01
Report Typos and Errors

# STFilterGetThreshold

Gets the threshold value gamma such that rho(lambda)>=gamma for eigenvalues lambda inside the wanted interval and rho(lambda)<gamma for those outside.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STFilterGetThreshold(ST st,PetscReal *gamma)

Not Collective

### Input Parameter

| st | - the spectral transformation context

### Output Parameter

| gamma | - the threshold value

### See Also

STFilterGetRange()

### Level

developer

### Location

src/sys/classes/st/impls/filter/filter.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages